Trait Scope
pub trait Scope:
Clone
+ Debug
+ Send
+ Sync {
// Required method
fn is_instr_in_scope(&self, instr: &[u8]) -> bool;
}Expand description
Defines an instruction scope for an architecture. This can be used to limit which parts of the instruction space are enumerated.
Required Methods
fn is_instr_in_scope(&self, instr: &[u8]) -> bool
fn is_instr_in_scope(&self, instr: &[u8]) -> bool
Returns true if and only if instr should be enumerated.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".